@@ -85,7 +85,7 @@ BAD_WORDS = ['okay','kinda','w','even','only','really','maybe','being','having',
             'does','four','might','ten','hum','six','once','either','eight','both','ah','o','d','myself','u',
             'ones','seven','huh','s','nine','few','thousand','anybody','somebody','everybody','hafta','someone',
             'yep','hey','anymore','kinda','seventy','yet','against','anyway','forty','ninety','wow','gotta',
-            'such','somewhere','may','bush','gore']
+            'such','somewhere','may','bush','gore','there','very','back','ever']
 MONOPHTHONGS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
 
 class WTManager(BulkManager):
